smartcard.pcsc.PCSCReader.PCSCReader

# ``smartcard`.`pcsc`.`PCSCReader`.`PCSCReader``

class documentation

`class PCSCReader(Reader):`

View In Hierarchy

PCSC reader class.

Class | `Factory` | Undocumented
Static Method | `readers` | Undocumented
Method | `__init__` | Constructs a new PCSC reader.
Method | `addtoreadergroup` | Add reader to a reader group.
Method | `createConnection` | Return a card connection thru PCSC reader.
Method | `removefromreadergroup` | Remove a reader from a reader group

Inherited from `Reader`:

Method | `__eq__` | Returns True if self==other (same name).
Method | `__hash__` | Returns a hash value for this object (self.name is unique).
Method | `__repr__` | Returns card reader name string for `object` calls.
Method | `__str__` | Returns card reader name string for str(object) calls.
Instance Variable | `name` | Undocumented

def readers(groups=[]):

Undocumented

def __init__(self, readername):
overrides `smartcard.reader.Reader.Reader.__init__`

Constructs a new PCSC reader.

def addtoreadergroup(self, groupname):
overrides `smartcard.reader.Reader.Reader.addtoreadergroup`

Add reader to a reader group.

def createConnection(self):
overrides `smartcard.reader.Reader.Reader.createConnection`

Return a card connection thru PCSC reader.

def removefromreadergroup(self, groupname):
overrides `smartcard.reader.Reader.Reader.removefromreadergroup`

Remove a reader from a reader group